import "./tasks/vcf2bed.wdl" as vcf2bed
import "./tasks/mergeBed.wdl" as mergeBed
import "./tasks/bedAnnotation.wdl" as bedAnnotation

workflow {{ project_name }} {
	File inputSamplesFile
	Array[Array[File]] inputSamples = read_tsv(inputSamplesFile)
	File breakpoint_directory
	String sample_name
	String cluster_config
	String disk_size

	scatter (sample in inputSamples){
		call vcf2bed.vcf2bed as vcf2bed {
			input:
			vcf=sample[0],
			vote_file=sample[1],
			chromo=sample[2],
			sample_name=sample_name,
			cluster_config=cluster_config,
			disk_size=disk_size	
		}
	}
	call mergeBed.mergeBed as mergeBed {
		input:
		chromo_filtered_bed=vcf2bed.chromo_filtered_bed,
		chromo_voted_bed=vcf2bed.chromo_voted_bed,
		sample_name=sample_name,
		cluster_config=cluster_config,
		disk_size=disk_size
	}
	call bedAnnotation.bedAnnotation as bedAnnotation {
		input:
		filtered_bed=mergeBed.filtered_bed,
		voted_bed=mergeBed.voted_bed,
		breakpoint_directory=breakpoint_directory,
		sample_name=sample_name,
		cluster_config=cluster_config,
		disk_size=disk_size
	}
}
